@@ -93,7 +93,7 @@ class AsyncioFactoryConnectTest(unittest.TestCase):
         @asyncio.coroutine
         def go():
             connection = yield from self.graph.connect()
-            resp = connection.send("1 + 1", handler=lambda x: x.data[0] * 2)
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
             while True:
                 msg = yield from resp.read()
                 if msg is None:
@@ -103,6 +103,22 @@ class AsyncioFactoryConnectTest(unittest.TestCase):
 
         self.loop.run_until_complete(go())
 
+    def test_add_handler(self):
+
+        @asyncio.coroutine
+        def go():
+            connection = yield from self.graph.connect()
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
+            resp.add_handler(lambda x: x ** 2)
+            while True:
+                msg = yield from resp.read()
+                if msg is None:
+                    break
+                self.assertEqual(msg, 16)
+            connection.conn.close()
+
+        self.loop.run_until_complete(go())
+
     def test_read_one_on_closed(self):
 
         @asyncio.coroutine
