@@ -112,7 +112,7 @@ class TornadoFactoryConnectTest(unittest.TestCase):
 
         async def go():
             connection = await self.graph.connect()
-            resp = connection.send("1 + 1", handler=lambda x: x.data[0] * 2)
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
             while True:
                 msg = await resp.read()
                 if msg is None:
@@ -122,6 +122,21 @@ class TornadoFactoryConnectTest(unittest.TestCase):
 
         self.loop.run_sync(go)
 
+    def test_add_handler(self):
+
+        async def go():
+            connection = await self.graph.connect()
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
+            resp.add_handler(lambda x: x ** 2)
+            while True:
+                msg = await resp.read()
+                if msg is None:
+                    break
+                self.assertEqual(msg, 16)
+            connection.conn.close()
+
+        self.loop.run_sync(go)
+
     def test_read_one_on_closed(self):
 
         async def go():
