@@ -94,7 +94,7 @@ class TrolliusFactoryConnectTest(unittest.TestCase):
         @trollius.coroutine
         def go():
             connection = yield From(self.graph.connect())
-            resp = connection.send("1 + 1", handler=lambda x: x.data[0] * 2)
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
             while True:
                 msg = yield From(resp.read())
                 if msg is None:
@@ -103,6 +103,22 @@ class TrolliusFactoryConnectTest(unittest.TestCase):
             connection.conn.close()
         self.loop.run_until_complete(go())
 
+    def test_add_handler(self):
+
+        @trollius.coroutine
+        def go():
+            connection = yield From(self.graph.connect())
+            resp = connection.send("1 + 1", handler=lambda x: x[0] * 2)
+            resp.add_handler(lambda x: x ** 2)
+            while True:
+                msg = yield From(resp.read())
+                if msg is None:
+                    break
+                self.assertEqual(msg, 16)
+            connection.conn.close()
+
+        self.loop.run_until_complete(go())
+
     def test_read_one_on_closed(self):
 
         @trollius.coroutine
